@@ -165,7 +165,7 @@ void translationSSA_full(int* riblocations, double* kelong, double* t_array, int
     MatrixXi X(1,N_rib);	
 
     X.setZero(1,N_rib);
-	for(int i=0; i <= N_rib; i++)	{
+	for(int i=0; i < N_rib; i++)	{
 		X(0,i) = x0[i];
 	}
 	
